@@ -5,6 +5,7 @@ from rest_framework.views import APIView
 from xj_thread.services.thread_category_service import ThreadCategoryService
 from xj_thread.services.thread_item_service import ThreadItemService
 from xj_thread.services.thread_list_service import ThreadListService
+from xj_user.services.user_detail_info_service import DetailInfoService
 from xj_user.utils.user_wrapper import user_authentication_force_wrapper, user_authentication_wrapper
 from ..join_list import JoinList
 from ..service.clock_service import ClockService
@@ -14,24 +15,34 @@ from ..service.enroll_subitem_record_service import EnrollSubitemRecordService
 from ..service.rule_service import RuleValueService
 from ..service.subitem_service import SubitemService
 from ..utils.custom_response import util_response
-from ..utils.custom_tool import parse_data, format_params_handle, request_params_wrapper, filter_result_field, flow_service_wrapper
+from ..utils.custom_tool import parse_data, format_params_handle, request_params_wrapper, filter_result_field, flow_service_wrapper, write_to_log
 
 
 class EnrollAPI(APIView):
 
     @require_http_methods(['POST'])
     @user_authentication_force_wrapper
-    def add(self, *args, user_info, **kwargs, ):
-        params = parse_data(self)
+    @request_params_wrapper
+    @flow_service_wrapper
+    def add(self, *args, user_info, request_params, **kwargs, ):
+        params = request_params
         # ============   字段验证处理 start ============
         user_id = user_info.get("user_id")
-        subitem__count = params.pop("subitem__count", 0)  # 项目清单数量
-        params.setdefault("subitems", [])  # 报名分项
         params.setdefault("user_id", user_id)  # 用户ID
-        try:
-            is_valuate = int(params.pop("is_valuate", 1))  # 是否重新验单，进行计价，补全没有传的参数
-        except Exception:
-            is_valuate = 0
+
+        params.setdefault("subitems", [])  # 报名分项
+        subitem__count = params.pop("subitem__count", 1)  # 报名分项 项目清单数量
+        enroll_subitem_status_code = params.pop("enroll_subitem_status_code", 242)  # 报名分项 状态码
+
+        # ============ 如果有计价id，并且需要重新计价，补全补全的参数  start ============
+        # try:
+        #     is_valuate = int(params.pop("is_valuate", 1))  # 是否重新验单，进行计价，补全没有传的参数
+        # except Exception:
+        #     is_valuate = 0
+
+        # if is_valuate and main_params.get("enroll_rule_group_id"):
+        #     print("params:", params)
+        # ============ 如果有计价id，并且需要重新计价，补全补全的参数  end ============
 
         # 信息表参数
         thread_params = format_params_handle(
@@ -80,14 +91,9 @@ class EnrollAPI(APIView):
                 raise Exception("没有找到对应的计价规则组ID")
             main_params.setdefault("enroll_rule_group_id", res[0].get("id"))
         except Exception as e:
-            pass
+            write_to_log(prefix="报名发布，绑定计价组ID异常", err_obj=e)
         # ============   绑定计价分组ID end ============
 
-        # ============ 如果有计价id，并且需要重新计价，补全补全的参数  start ============
-        if is_valuate and main_params.get("enroll_rule_group_id"):
-            print("params:", params)
-        # ============ 如果有计价id，并且需要重新计价，补全补全的参数  end ============
-
         # ============ 信息表添加  start ============
         sid = transaction.savepoint()
         thread_id = thread_params.get("thread_id")
@@ -113,10 +119,8 @@ class EnrollAPI(APIView):
         # ============ 报名分项添加  start ============
         for item_params in params.get("subitems", []):
             item_params.setdefault("enroll_id", main_instance.get('id'))
-            item_params.setdefault("enroll_subitem_status_code", 242)
-            # print("item_params", item_params)
-            if subitem__count:
-                item_params["count"] = subitem__count
+            item_params.setdefault("enroll_subitem_status_code", enroll_subitem_status_code)
+            item_params.setdefault("count", subitem__count)
             data, err = SubitemService.add(item_params)
             if err:
                 transaction.savepoint_rollback(sid)
@@ -128,28 +132,37 @@ class EnrollAPI(APIView):
 
     @require_http_methods(['GET'])
     @user_authentication_wrapper
-    def detail(self, *args, user_info=None, **kwargs, ):
+    @request_params_wrapper
+    def detail(self, *args, user_info=None, request_params, **kwargs, ):
         # 参数验证
         if user_info is None:
             user_info = {}
 
-        params = parse_data(self)
+        params = request_params
+        default_remove_fields = [
+            "real_name", "sex", "birth", "tags", "signature", "avatar", "cover", "language", "more",
+            "id_card_front", "id_card_back", "real_name_is_pass", "id_card",
+            "certificate", "work experience", "qualification_certificate", "audit_status",
+            "score", "user_name", "phone", "email", "register_time",
+            "user_info", "wechat_openid", "is_deleted",
+        ]
         filter_fields = params.pop("filter_fields", None)
-        remove_fields = params.pop("remove_fields", None)
+        remove_fields = params.pop("remove_fields", default_remove_fields)
+
         enroll_id = kwargs.get("enroll_id", None) or params.pop("enroll_id", None)
         if not enroll_id:
             return util_response(err=1000, msg="参数错误:enroll_id不可以为空")
 
         user_id = user_info.get("user_id", None)
-        # 获取详情
+
+        # 获取用户详情
         data, err = EnrollServices.enroll_detail(enroll_id, user_id=user_id)
         if err:
             return util_response(err=1001, msg=err)
 
         # 用户数据拼接
-        # todo 隐患就是一个活动报名人数非常多的时候 下面服务效率会非常低,当数据连比较大的时候注释下面这一行仅仅返回用户ID
-        # users = DetailInfoService.get_list_detail({}, data["enroll_user_ids"])
-        # data["enroll_user_info"] = [{"user_id": i["user_id"], 'nickname': i["nickname"], 'user_name': i["user_name"], 'full_name': i["full_name"]} for i in users]
+        push_user_info, user_err = DetailInfoService.get_detail(user_id=user_id)
+        data.update(push_user_info)
 
         # 信息表 数据拼接
         thread_list, err = ThreadListService.search([data.get("thread_id")])
@@ -160,8 +173,8 @@ class EnrollAPI(APIView):
         data["price"] = round(data["price"] or 0, 2)
 
         # 字段过滤
-        filter_fields = filter_fields.split(";") if filter_fields else None
-        remove_fields = remove_fields.split(";") if remove_fields else None
+        filter_fields = filter_fields.split(";") if filter_fields and isinstance(filter_fields, str) else filter_fields
+        remove_fields = remove_fields.split(";") if remove_fields and isinstance(remove_fields, str) else remove_fields
         data = format_params_handle(data, filter_filed_list=filter_fields, remove_filed_list=remove_fields, is_remove_null=False)
         # 响应数据
         if err:
